@@ -1,8 +1,10 @@
 `clustering_w` <-
-function(net,measure="mi"){
+function(net,measure="mi",subsample=1,seed=NULL){
   # Ensure that the network conforms to the tnet standard
   if (is.null(attributes(net)$tnet))                      net <- as.tnet(net, type = "weighted one-mode tnet")
   if (attributes(net)$tnet != "weighted one-mode tnet")   stop("Network not loaded properly")
+  if(!is.null(seed))
+    set.seed(as.integer(seed))
 
   # List of edges split by sender
   net.list.j <- split(net[,"j"], net[,"i"])
@@ -15,10 +17,24 @@ function(net,measure="mi"){
   rm(net.list.wij)
   # Create a list of triplets
   ks <- unlist(lapply(net.list.k, length))
-  net.list.i <- net[rep(1:nrow(net), ks),"i"]
-  net.list.wij <- net[rep(1:nrow(net), ks),"w"]
-  net.list.k <- unlist(net.list.k)
-  net.list.wjk <- unlist(net.list.wjk)
+  if(subsample!=1) {
+    if(subsample<1) {
+      index <- sample.int(sum(ks), round(sum(ks)*subsample))
+    } else {
+      index <- sample.int(sum(ks), as.integer(subsample))
+    }
+    index <- index[order(index)]
+    net.list.i <- net[rep(1:nrow(net), ks),"i"][index]
+    net.list.wij <- net[rep(1:nrow(net), ks),"w"][index]
+    net.list.k <- unlist(net.list.k)[index]
+    net.list.wjk <- unlist(net.list.wjk)[index]
+  } else {
+    net.list.i <- net[rep(1:nrow(net), ks),"i"]
+    net.list.wij <- net[rep(1:nrow(net), ks),"w"]
+    net.list.k <- unlist(net.list.k)
+    net.list.wjk <- unlist(net.list.wjk)
+    
+  }
   triplets <- data.frame(i=net.list.i, k=net.list.k, wij=net.list.wij, wjk=net.list.wjk)
   rm(ks, net.list.i, net.list.k, net.list.wij, net.list.wjk)
   # Remove 1-step loops, i->j->i
